@@ -3,17 +3,16 @@
 import gym
 import pygame
 from examples.test_env import TestEnv
-from algorithms.rl import QLearner
+from algorithms.rl import RL
 import itertools
 
 
 class GridSearch:
     @staticmethod
     def Q_learning_grid_search(env, epsilon_decay, iters):
-        QL = QLearner(env)
         for i in itertools.product(epsilon_decay, iters):
             print("running -- with epsilon decay: ", i[0],  " iterations: ", i[1])
-            Q, V, pi, Q_track, pi_track = QL.q_learning(epsilon_decay_ratio=i[0], n_episodes=i[1])
+            Q, V, pi, Q_track, pi_track = RL(env).q_learning(epsilon_decay_ratio=i[0], n_episodes=i[1])
 
 
 if __name__ == "__main__":
